import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AchieveApplyService } from '../service/achieveApply.service';
import {
  CDTO_achieveApply,
  CVO_achieveApply,
  FVO_achieveApply,
  QDTO_achieveApply,
  QVO_achieveApply,
  UDTO_achieveApply,
  UVAO_achieveApply,
} from '../interface/achieveApply.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['成果申请表'])
@Controller('/achieveApply')
export class AchieveApplyController extends BaseController {
  @Inject()
  service: AchieveApplyService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_achieveApply })
  async create(@Body() data: CDTO_achieveApply) {
    const dbData = await this.service.create(data);
    const result = new CVO_achieveApply(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_achieveApply })
  async query(
    @Query() filter: QDTO_achieveApply,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_achieveApply(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_achieveApply })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_achieveApply(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_achieveApply })
  async update(@Param('id') id: string, @Body() body: UDTO_achieveApply) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
