import {
  Body,
  Config,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import {
  BaseController,
  FrameworkErrorEnum,
  ServiceError,
} from 'free-midway-component';
import { AchieveExpertService } from '../service/achieveExpert.service';
import {
  CDTO_achieveExpert,
  CVO_achieveExpert,
  FVO_achieveExpert,
  QDTO_achieveExpert,
  QVO_achieveExpert,
  UDTO_achieveExpert,
  UVAO_achieveExpert,
  LoginDTO,
  ResetPasswordDTO,
  LoginVO,
} from '../interface/achieveExpert.interface';
import {
  ApiOperation,
  ApiQuery,
  ApiResponse,
  ApiTags,
} from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { JwtService } from '@midwayjs/jwt';
import get = require('lodash/get');
@ApiTags(['会审专家表'])
@Controller('/achieveExpert')
export class AchieveExpertController extends BaseController {
  @Inject()
  service: AchieveExpertService;

  @Inject()
  jwtService: JwtService;

  @Config('jwt.secret')
  jwtSecret;

  @Config('jwt.expiresIn')
  jwtExpiresIn;

  @Post('/login')
  @Validate()
  async login(@Body() body: LoginDTO) {
    const data = await this.service.findUserToLogin(body);
    let vo = new LoginVO(data);
    vo = JSON.parse(JSON.stringify(vo));
    const token = await this.jwtService.sign(vo, this.jwtSecret, {
      expiresIn: this.jwtExpiresIn,
    });
    return token;
  }

  @Post('/rp')
  @ApiOperation({ description: '修改密码' })
  async resetPassword(@Body() body: ResetPasswordDTO) {
    // 获取用户token中的登录信息
    const user_id = get(this.ctx, 'user._id');
    if (!user_id)
      throw new ServiceError('未找到用户信息', FrameworkErrorEnum.NOT_LOGIN);
    // 查询用户
    const user = await this.service.fetch(user_id);
    if (!user)
      throw new ServiceError('未找到用户', FrameworkErrorEnum.NOT_FOUND_DATA);
    // 修改密码
    await this.service.updateOne(user_id, body);
    // 返回结果
    return 'ok';
  }

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_achieveExpert })
  async create(@Body() data: CDTO_achieveExpert) {
    const dbData = await this.service.create(data);
    const result = new CVO_achieveExpert(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_achieveExpert })
  async query(
    @Query() filter: QDTO_achieveExpert,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_achieveExpert(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_achieveExpert })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_achieveExpert(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_achieveExpert })
  async update(@Param('id') id: string, @Body() body: UDTO_achieveExpert) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
