import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CertFileService } from '../service/certFile.service';
import {
  CDTO_certFile,
  CVO_certFile,
  FVO_certFile,
  QDTO_certFile,
  QVO_certFile,
  UDTO_certFile,
  UVAO_certFile,
} from '../interface/certFile.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['证书单独上传'])
@Controller('/certFile')
export class CertFileController extends BaseController {
  @Inject()
  service: CertFileService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_certFile })
  async create(@Body() data: CDTO_certFile) {
    const dbData = await this.service.create(data);
    const result = new CVO_certFile(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_certFile })
  async query(
    @Query() filter: QDTO_certFile,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_certFile(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_certFile })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_certFile(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_certFile })
  async update(@Param('id') id: string, @Body() body: UDTO_certFile) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
