import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ExamLogsService } from '../service/examLogs.service';
import {
  CDTO_examLogs,
  CVO_examLogs,
  FVO_examLogs,
  QDTO_examLogs,
  QVO_examLogs,
  UDTO_examLogs,
  UVAO_examLogs,
} from '../interface/examLogs.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['审核记录表'])
@Controller('/examLogs')
export class ExamLogsController extends BaseController {
  @Inject()
  service: ExamLogsService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_examLogs })
  async create(@Body() data: CDTO_examLogs) {
    const dbData = await this.service.create(data);
    const result = new CVO_examLogs(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_examLogs })
  async query(
    @Query() filter: QDTO_examLogs,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_examLogs(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_examLogs })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_examLogs(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_examLogs })
  async update(@Param('id') id: string, @Body() body: UDTO_examLogs) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
