import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ExpertExamService } from '../service/expertExam.service';
import {
  CDTO_expertExam,
  CVO_expertExam,
  FVO_expertExam,
  QDTO_expertExam,
  QVO_expertExam,
  UDTO_expertExam,
  UVAO_expertExam,
} from '../interface/expertExam.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['专家评分会审表'])
@Controller('/expertExam')
export class ExpertExamController extends BaseController {
  @Inject()
  service: ExpertExamService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_expertExam })
  async create(@Body() data: CDTO_expertExam) {
    const dbData = await this.service.create(data);
    const result = new CVO_expertExam(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_expertExam })
  async query(
    @Query() filter: QDTO_expertExam,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_expertExam(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_expertExam })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_expertExam(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_expertExam })
  async update(@Param('id') id: string, @Body() body: UDTO_expertExam) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
